@@ -49,7 +49,7 @@ class Input:
         self.message_id = message_id
         self.bypass_count = bypass_count
         if timeout:
-            self.timer = asyncio.get_event_loop().call_later(timeout, self.cancel)
+            self.timer = asyncio.get_running_loop().call_later(timeout, self.cancel)
 
     def done(self, result):
         self.future.set_result(result)
